@@ -40,7 +40,7 @@ G_BEGIN_DECLS
  * application compile time, rather than from the library linked
  * against at application run time.
  */
-#define GTK_SOURCE_MINOR_VERSION (4)
+#define GTK_SOURCE_MINOR_VERSION (6)
 
 /**
  * GTK_SOURCE_MICRO_VERSION:
@@ -49,7 +49,7 @@ G_BEGIN_DECLS
  * application compile time, rather than from the library linked
  * against at application run time.
  */
-#define GTK_SOURCE_MICRO_VERSION (0)
+#define GTK_SOURCE_MICRO_VERSION (1)
 
 
 /**
@@ -107,6 +107,16 @@ G_BEGIN_DECLS
  */
 #define GTK_SOURCE_VERSION_5_4 (G_ENCODE_VERSION (5, 4))
 
+/**
+ * GTK_SOURCE_VERSION_5_6:
+ *
+ * A macro that evaluates to the 5.6 version of GtkSourceView,
+ * in a format that can be used by the C pre-processor.
+ *
+ * Since: 5.6
+ */
+#define GTK_SOURCE_VERSION_5_6 (G_ENCODE_VERSION (5, 6))
+
 /* Define GTK_SOURCE_VERSION_CUR_STABLE */
 #ifndef __GTK_DOC_IGNORE__
 #  if (GTK_SOURCE_MINOR_VERSION % 2)
@@ -200,6 +210,14 @@ G_BEGIN_DECLS
 #endif
 #endif /* __GTK_DOC_IGNORE__ */
 
+#ifndef __GTK_DOC_IGNORE__
+#if GTK_SOURCE_VERSION_MAX_ALLOWED < GTK_SOURCE_VERSION_5_6
+#define GTK_SOURCE_AVAILABLE_IN_5_6 G_UNAVAILABLE(5, 6) _GTK_SOURCE_EXTERN
+#else
+#define GTK_SOURCE_AVAILABLE_IN_5_6 _GTK_SOURCE_EXTERN
+#endif
+#endif /* __GTK_DOC_IGNORE__ */
+
 GTK_SOURCE_AVAILABLE_IN_ALL
 guint    gtk_source_get_major_version (void);
 GTK_SOURCE_AVAILABLE_IN_ALL
